package com.jusfoun.ydylsz.controller.dxp;

import java.util.List;

import com.jusfoun.ydylsz.constants.ApiTag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.CompanyService;
import com.jusfoun.ydylsz.vo.CompanyQueryVO;
import com.jusfoun.ydylsz.vo.CompanyVO;
import com.jusfoun.ydylsz.vo.ConpanyStyle;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;


/**
 * @author huangxing
 * @version 1.0
 * @Title TzSlqyController
 * @ProjectName 企业信息Controller
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "企业信息", tags = "企业信息维护")
@Slf4j
public class CompanyController {

	@Autowired
	private CompanyService companyService;

	/**
	 * @author huangxing
	 * @Description 获取企业信息列表
	 * @param qymc 社会统一行政编码，企业名称，企业类型，企业性质，法定代表人
	 * @return 企业信息列表
	 */
	@ApiOperation(value = "获取企业信息列表", notes = "参数：企业名称", tags = {"企业信息维护", ApiTag.HOME_PAGE})
	@GetMapping(value = "/companyList/{qymc}")
    public RootResult<List<CompanyVO>> getCompanyList(@PathVariable("qymc") String qymc) {
        RootResult<List<CompanyVO>> r = new RootResult<>();
		try {
            if ("-1".equals(qymc)) {
                qymc = null; // -1 查询全部
            }
			r.setData(companyService.getCompanyList(qymc));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
    }

	@ApiOperation(value = "获取企业信息列表--加权限", notes = "参数：企业名称", tags = {"企业信息维护", ApiTag.HOME_PAGE})
	@GetMapping(value = "/companyList/{qymc}/{roleId}")
	public RootResult<List<CompanyVO>> getCompanyRoleList(@PathVariable("qymc") String qymc,@PathVariable("roleId")
			String	roleId) {
		RootResult<List<CompanyVO>> r = new RootResult<>();
		try {
            r.setData(companyService.getCompanyRoleList(qymc, roleId));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
	}


	@ApiOperation(value = "获取企业信息列表", notes = "参数：企业查询参数", tags = {ApiTag.HOME_PAGE})
	@PostMapping(value = "/companyList/{pageNo}/{pageSize}")
    public RootResult<PageInfo<CompanyVO>> getCompanyInfoList(@RequestBody CompanyQueryVO companyQueryVO, @PathVariable("pageNo") Integer pageNo, @PathVariable("pageSize") Integer pageSize) {
        RootResult<PageInfo<CompanyVO>> r = new RootResult<>();
		try {
			r.setData(companyService.getCompanyList(companyQueryVO,pageNo,pageSize));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
    }


	@ApiOperation(value = "获取库存信息列表", notes = "参数：库存名称")
	@PostMapping(value = "/kucunList/{pageNo}/{pageSize}")
    public RootResult<PageInfo<CompanyVO>> kucunList(@RequestBody CompanyVO companyVO ,@PathVariable("pageNo") Integer pageNo,@PathVariable("pageSize") Integer pageSize) {
        RootResult<PageInfo<CompanyVO>> r = new RootResult<>();
		try {
			r.setData(companyService.kucunList(companyVO,pageNo,pageSize));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
    }

	@ApiOperation(value = "获取库存信息列表--权限", notes = "参数：库存名称", tags = {ApiTag.HOME_PAGE})
	@PostMapping(value = "/kucunRoleList/{pageNo}/{pageSize}")
	public RootResult<PageInfo<CompanyVO>> kucunRoleList(@RequestBody CompanyVO companyVO ,@PathVariable("pageNo") Integer pageNo,@PathVariable("pageSize") Integer pageSize) {
		RootResult<PageInfo<CompanyVO>> r = new RootResult<>();
		try {
			r.setData(companyService.kucunRoleList(companyVO,pageNo,pageSize));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
	}


	@ApiOperation(value = "获取描点信息", notes = "参数：库区编号")
	@GetMapping(value = "/companystyle/{kqbm}")
    public RootResult<List<ConpanyStyle>> companystyle(@PathVariable("kqbm") String kqbm) {
        RootResult<List<ConpanyStyle>> r = new RootResult<>();
		try {
			r.setData(companyService.companystyle(kqbm));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
    }

	@ApiOperation(value = "获取库区信息", notes = "参数：库区编号")
	@GetMapping(value = "/selectQybm/{qybm}")
	public RootResult<String> selectQybm(@PathVariable("qybm") String qybm) {
		RootResult<String> r = new RootResult<>();
		try {
			r.setData(companyService.selectByQybm(qybm));
		} catch (Exception e) {
			e.printStackTrace();
		}
		return r;
	}
}
