package com.jusfoun.ydylsz.controller.dxp;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.DXPTFZYJGService;
import com.jusfoun.ydylsz.service.PestService;
import com.jusfoun.ydylsz.service.TemperatureService;
import com.jusfoun.ydylsz.util.WebUtil;
import com.jusfoun.ydylsz.vo.DXPTFZYJGVO;
import com.jusfoun.ydylsz.vo.DYglqkVO;
import com.jusfoun.ydylsz.vo.DcflqkqkVO;
import com.jusfoun.ydylsz.vo.XwkChjc;
import com.jusfoun.ydylsz.vo.XwkSfjcjl;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(description = "粮情卡信息", tags = "粮情卡信息")
@RestController
@RequestMapping("/lqk")
public class LqkController {

    @Autowired
    private PestService pestService;

    //通风信息获取
    @ApiOperation(value = "粮情卡", notes = "参数：统一社会信用代码")
    @GetMapping(value = "/info/{hwbm}")
    public RootResult<Object> info(@PathVariable("hwbm") String hwbm) {
        RootResult<Object> r = new RootResult<>();
        try {
            DcflqkqkVO result = pestService.getLqk(hwbm);
            r.setData(result);
            r.setCode(200);
            r.setMsg("请求成功");
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "油罐粮情卡", notes = "参数：统一社会信用代码")
    @GetMapping(value = "/yginfo/{hwbm}/{ygly}")
    public RootResult<Object> yginfo(@PathVariable("hwbm") String hwbm, @PathVariable("ygly") String ygly) {
        RootResult<Object> r = new RootResult<Object>();
        try {
            DYglqkVO result = pestService.getYgLqk(hwbm, ygly);
            r.setData(result);
            r.setCode(200);
            r.setMsg("请求成功");
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "历史粮情卡分页列表", notes = "粮情卡对象")
    @PostMapping(value = "history/page")
    public RootResult<Object> pageHistoryLqk(@RequestBody DcflqkqkVO dcflqkqkVO,
                                             @RequestParam("pageNum") int pageNum,
                                             @RequestParam("pageSize") int pageSize) {
        RootResult<Object> result = new RootResult<>();
        try {
            PageInfo<DcflqkqkVO> data = pestService.pageHisLqk(dcflqkqkVO, pageNum, pageSize);
            result.setData(data);
            result.setCode(200);
            result.setMsg("请求成功");
        } catch (Exception e) {
            result.setMsg(e.getMessage());
            e.printStackTrace();
            result.setCode(500);
        }
        return result;
    }

    @ApiOperation(value = "根据id查询历史粮情卡详情", notes = "粮情卡对象")
    @GetMapping(value = "history/detail")
    public RootResult<Object> getHistoryLqkById(@RequestParam("id") String id,
                                             @RequestParam(value = "dataOrg", defaultValue = "1") int dataOrg) {
        RootResult<Object> result = new RootResult<>();
        try {
            DcflqkqkVO data = pestService.getLqkById(id, dataOrg);
            result.setData(data);
            result.setCode(200);
            result.setMsg("请求成功");
        } catch (Exception e) {
            result.setMsg(e.getMessage());
            e.printStackTrace();
            result.setCode(500);
        }
        return result;
    }
}
