package com.jusfoun.ydylsz.controller.dxp;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.DXPTFZYJGService;
import com.jusfoun.ydylsz.service.PestService;
import com.jusfoun.ydylsz.service.TemperatureService;
import com.jusfoun.ydylsz.util.WebUtil;
import com.jusfoun.ydylsz.vo.DXPTFZYJGVO;
import com.jusfoun.ydylsz.vo.XwkChjc;
import com.jusfoun.ydylsz.vo.XwkSfjcjl;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/pest")
@Api(description="虫害信息")
public class PestController {

	@Autowired
	private PestService pestService;
	
	//通风信息获取
	@ApiOperation(value = "虫害列表", notes = "参数：统一社会信用代码")
	@GetMapping(value = "/list/{cfbh}")
	public RootResult<Object> list(@PathVariable("cfbh") String cfbh){
		RootResult<Object> r = new RootResult<Object>();
		try {
			List<XwkChjc> result = pestService.list(cfbh);
			r.setData(result);
			r.setCode(200);
			r.setMsg("请求成功");
		} catch (Exception e) {
			r.setMsg(e.getMessage());
			e.printStackTrace();
			r.setCode(500);
		}
		return r;
	}
	
	//通风信息获取
		@ApiOperation(value = "虫害详情", notes = "参数：统一社会信用代码")
		@GetMapping(value = "/info/{chjcid}")
		public RootResult<Object> info(@PathVariable("chjcid") String chjcid){
			RootResult<Object> r = new RootResult<Object>();
			try {
				XwkChjc result = pestService.info(chjcid);
				r.setData(result);
				r.setCode(200);
				r.setMsg("请求成功");
			} catch (Exception e) {
				r.setMsg(e.getMessage());
				e.printStackTrace();
				r.setCode(500);
			}
			return r;
		}
		
		@ApiOperation(value = "虫害分页", notes = "参数：统一社会信用代码")
		@PostMapping(value = "/page/{pageNum}/{pageSize}")
		public RootResult<Object> page(@RequestBody XwkChjc xwkChjc,@PathVariable("pageNum") Integer pageNum,@PathVariable("pageSize") Integer pageSize){
			RootResult<Object> r = new RootResult<Object>();
			try {
				PageInfo<XwkChjc> result = pestService.page(xwkChjc,pageNum,pageSize);
				r.setData(result);
				r.setCode(200);
				r.setMsg("请求成功");
			} catch (Exception e) {
				r.setMsg(e.getMessage());
				e.printStackTrace();
				r.setCode(500);
			}
			return r;
		}
}
