package com.jusfoun.ydylsz.controller.dxp;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.pojo.InventoryQueryVO;
import com.jusfoun.ydylsz.service.LsKcxxService;
import com.jusfoun.ydylsz.vo.CompositeQueryVo;
import com.jusfoun.ydylsz.vo.DCfxxsjyVO;
import com.jusfoun.ydylsz.vo.HouseVO;
import com.jusfoun.ydylsz.vo.out.base.RootResult;
import com.unis.common.utils.JxlModelExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Assert;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * @author by PIG
 * 2022/4/12 14
 */
@Api(tags = "综合查询 库级实物", value = "ZhcxController", description = "综合查询库级实物")
@RestController
@RequestMapping("/zhcx")
@Slf4j
public class ZhcxController {

    @Autowired
    private LsKcxxService lsKcxxService;

    @ApiOperation(value = "综合查询 库级实物库存查询 ", notes = "")
    @PostMapping(value = "/page/{pageNum}/{pageSize}")
    public RootResult<JSONObject> pageFoodStocks(@RequestBody CompositeQueryVo queryVo,
                                       @PathVariable("pageNum") Integer pageNum,
                                       @PathVariable("pageSize") Integer pageSize) {
        RootResult<JSONObject> r = new RootResult<>();
        try {
            queryVo.fillRkny();
            PageInfo<InventoryQueryVO> pageInfo = lsKcxxService.listKcxx(queryVo, pageNum, pageSize);
            InventoryQueryVO total = lsKcxxService.getTotal(queryVo);
            JSONObject data = JSONObject.parseObject(JSONObject.toJSONString(pageInfo));
            data.put("countInfo", total);
            r.setData(data);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return r;
    }

    @ApiOperation(value = "综合查询 库级实物库存明细 ", notes = "")
    @PostMapping(value = "/page_detail/{pageNum}/{pageSize}")
    public RootResult<JSONObject> pageFoodStocksDetail(@RequestBody CompositeQueryVo queryVo,
                                       @PathVariable("pageNum") Integer pageNum,
                                       @PathVariable("pageSize") Integer pageSize) {
        RootResult<JSONObject> r = new RootResult<>();
        try {
            queryVo.fillRkny();
            PageInfo<DCfxxsjyVO> pageInfo = lsKcxxService.listKcxxDetail(queryVo, pageNum, pageSize);
            DCfxxsjyVO total = lsKcxxService.getDetailTotal(queryVo);
            JSONObject data = JSONObject.parseObject(JSONObject.toJSONString(pageInfo));
            data.put("countInfo", total.getKcslStr());
            r.setData(data);
        } catch (Exception e) {
            r.setData(new JSONObject());
            r.setCode(500);
            e.printStackTrace();
        }
        return r;
    }


    @ApiOperation(value = "库级实物综合查询导出")
    @PostMapping(value = "/v2/exportKjsw")
    public void exportGssw(HttpServletRequest request, HttpServletResponse response,
                           @RequestBody CompositeQueryVo queryVO,
                           @RequestParam(value= "fields", required = false) String fields) throws IOException {
        PageInfo<InventoryQueryVO> pageInfo = lsKcxxService.listKcxx(queryVO, 1, Integer.MAX_VALUE);
        try {
            List dataList = JSONArray.parseArray(JSONObject.toJSONString(pageInfo.getList()), Map.class);
            //fileName导出文件名
            String fileName = "库级实物综合查询.xls";
            //sheetName表格名
            String sheetName = "综合查询";
            //headMap表头Map, key为属性名, value为展示名,根据实际情况修改
            LinkedHashMap<String, String> headMap = new LinkedHashMap<>();
            headMap.put("sskdmc", "承储库点");
            headMap.put("sjcblkc", "市级储备粮库存数量");
            headMap.put("xmsl", "小麦");
            headMap.put("dgsl", "稻谷");
            headMap.put("dmsl", "大米");
            headMap.put("xmfsl", "小麦粉");
            headMap.put("sjcbykc", "市级储备油库存数量");
            headMap.put("yysl", "原油");
            headMap.put("cpysl", "成品油");
            JxlModelExcelUtil.exportExcel(request, response, fileName, dataList, sheetName, headMap);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @ApiOperation(value = "库级实物综合查询明细导出")
    @PostMapping(value = "/v2/exportKjswDetail")
    public void exportGsswDetail(HttpServletRequest request, HttpServletResponse response,
                                 @RequestBody CompositeQueryVo queryVO,
                                 @RequestParam(value= "fields", required = false) String fields) throws IOException {
        PageInfo<DCfxxsjyVO> pageInfo = lsKcxxService.listKcxxDetail(queryVO, 1, Integer.MAX_VALUE);
        List dataList = JSONArray.parseArray(JSONObject.toJSONString(pageInfo.getList()), Map.class);
        //fileName导出文件名
        String fileName= "库级实物综合查询详情.xls";
        //sheetName表格名
        String sheetName= "综合查询详情";
        //headMap表头Map, key为属性名, value为展示名,根据实际情况修改
        LinkedHashMap<String, String> headMap= new LinkedHashMap<>();
        headMap.put("kdmc", "承储库点");
        headMap.put("cfmc", "仓号");
        headMap.put("lspzmc", "品种");
        headMap.put("kcslStr", "数量");
        headMap.put("nd", "生产年份");
        headMap.put("djbm", "等级");
        headMap.put("rksjks", "入库年月");
        JxlModelExcelUtil.exportExcel(request, response, fileName, dataList, sheetName, headMap);
    }


    @ApiOperation(value = "条件查询 货位库存", notes = "{\"kddm\":\"\",\"lypz\":\"\", \"gbcode\":\"\"}", tags = {"综合查询 库级实物", "三方质检"})
    @PostMapping(value = "/listDataByParams")
    public RootResult<JSONObject> listDataByParams(@RequestBody JSONObject params) {
        log.info("参数 {}", params);
        RootResult<JSONObject> r = new RootResult<>();
        JSONObject jsonObject = new JSONObject();
        try {
            String kddm = params.getString("kddm");
            String gbcode = params.getString("gbcode");
            if (StringUtils.isBlank(kddm) || StringUtils.isBlank(gbcode)) {
                r.setMsg("参数不能为null");
                return r;
            }
            List<HouseVO> dataList = lsKcxxService.listDataByParams(params);
            jsonObject.put("data", dataList);
            r.setData(jsonObject);
        } catch (Exception e) {
            r.setData(jsonObject);
            r.setCode(500);
            e.printStackTrace();
        }
        return r;
    }
}
