package com.jusfoun.ydylsz.pojo;

import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.apache.commons.lang.StringUtils;

import javax.persistence.Column;
import java.io.Serializable;
import java.math.BigDecimal;
import java.text.DecimalFormat;

/**
 * @author by PIG
 * @date 2022/2/10 10
 */
@Data
@JsonInclude(value = JsonInclude.Include.NON_NULL)
@ApiModel(value = "库存查询")
public class InventoryQueryVO implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "所属库点编码")
    @Column(name="sskddm")
    private String sskddm; // 所属库点编码

    @ApiModelProperty(value = "所属库点名称")
    @Column(name = "sskdmc")
    private String sskdmc; // 所属库点名称

    @ApiModelProperty(value = "市级储备粮库存")
    @Column(name = "sjcblkc")
    private String sjcblkc;

    @ApiModelProperty(value = "小麦库存量")
    @Column(name="xmsl")
    private String xmsl;
    @ApiModelProperty(value = "稻谷库存量")
    @Column(name="dgsl")
    private String dgsl;
    @ApiModelProperty(value = "大米")
    @Column(name="dmsl")
    private String dmsl;
    @ApiModelProperty(value = "小麦粉")
    @Column(name="xmfsl")
    private String xmfsl;

    @ApiModelProperty(value = "储备油库存")
    @Column(name="sjcbykc")
    private String sjcbykc;

    @ApiModelProperty(value = "原油")
    @Column(name="yysl")
    private String yysl;

    @ApiModelProperty(value = "成品油")
    @Column(name="cpysl")
    private String cpysl;

    public void zeroToNull() {
        if ("0.0".equals(this.sjcbykc)) {
            this.sjcbykc = null;
        }
        if ("0.0".equals(this.sjcblkc)) {
            this.sjcblkc = null;
        }
    }

    /**
     * <br/> 整数数量去掉小数位的0  100.00 -> 100
     * <br/> 小数补位 三位小数 100.10 -> 100.100
     * <br/> 0转null 0 -> null
     */
    public void numberFmt() {
        this.xmsl = numberFmt(this.xmsl);
        this.dgsl = numberFmt(this.dgsl);
        this.dmsl = numberFmt(this.dmsl);
        this.xmfsl = numberFmt(this.xmfsl);
        this.yysl = numberFmt(this.yysl);
        this.cpysl = numberFmt(this.cpysl);
        this.sjcblkc = numberFmt(this.sjcblkc);
        this.sjcbykc = numberFmt(this.sjcbykc);
    }

    /**
     *
     * @param n 要转换的数字字符
     * @return 转换后的字符
     */
    private String numberFmt(String n) {
        if (null == n) {
            return null;
        }
        DecimalFormat decimalFormat = new DecimalFormat("###################.###########");
        BigDecimal b = new BigDecimal(n);
        String lessNum = decimalFormat.format(b.doubleValue());
        if (StringUtils.contains(lessNum, ".")) {
            DecimalFormat df = new DecimalFormat("0.000");
            return df.format(b);
        }else if("0".equals(lessNum)){
            return null;
        }else {
            return lessNum;
        }
    }
}
