package com.jusfoun.ydylsz.service;



import com.jusfoun.ydylsz.mapper.FileMapper;
import com.jusfoun.ydylsz.util.FileTool;
import com.jusfoun.ydylsz.util.PathTool;
import com.jusfoun.ydylsz.util.FileUtil;
import com.jusfoun.ydylsz.utils.ImgUtil;
import com.jusfoun.ydylsz.vo.SysResource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;

@Service("fileService")
public class FileService {
    @Autowired
    private FileMapper fileMapper;

    private Logger log = LoggerFactory.getLogger(this.getClass());

    private static String IMG_POSTFIX = "GIF,JPG,JPEG,PNG,BMP";

    public SysResource uploadFile(HttpServletRequest request, Date date, String uploadPath, MultipartFile file, int width, int height){
        SysResource res = new SysResource();
        if(file.isEmpty()){
            res.setUploadStatus(false);
            log.error("上传失败，因为文件是空的");
            return res;
        }
        try {
			/*String newFolder = DateUtil.getNormalDayDate() + "/";//文件夹名称，一天生成一个
			String originalName = file.getOriginalFilename();//文件原始名称
			String postfix = originalName.substring(originalName.lastIndexOf(".") + 1);//后缀名称
			String newName = CommonUtil.getRandomFileName() + "." + postfix;//文件新名称，随机数加时间防止重复
			String resOriginalUrl = newFolder + "ori_" +  newName;//原始文件相对路径
			String resScaleUrl = newFolder + "scale_" +  newName;//压缩文件相对路径
			FileUtil.writeFile(uploadPath + newFolder, "ori_" +  newName, file.getBytes());*/
            String originalName = file.getOriginalFilename();//文件原始名称
            String postfix = FileTool.getFileExt(originalName);//后缀名称
            String newName = PathTool.makeWebpicName(originalName,date);//文件新名称，随机数加时间防止重复
            String resOriginalUrl = PathTool.readAbsolutePath(request,newName);//原始文件相对路径
            String scaleFileName=PathTool.makeScaleFileName(newName,date);
            String resScaleUrl =PathTool.readScaleAbsolutePath(request,scaleFileName);//压缩文件相对路径
            FileUtil.writeFile(uploadPath , newName, file.getBytes());

            res.setUploadStatus(true);
            res.setCreateTime(new Date());
            res.setResName(originalName);
            res.setResOriginalUrl(resOriginalUrl);
            res.setResCutUrl("");
            res.setResScaleUrl("");
            res.setResSize(Integer.valueOf(String.valueOf(file.getSize())));
            res.setResStatus(0);
            res.setResType(postfix);
            String[] arr = IMG_POSTFIX.split(",");
            Boolean isImg = false;
            for (String str : arr) {
                if(str.equals(postfix.toUpperCase())){
                    isImg = true;
                    break;
                }
            }
            String parentPath=PathTool.readParentWebPath(request,newName);
            if(isImg){//对图片进行处理
			/*	ImgUtil.compressPic(uploadPath + resOriginalUrl, uploadPath + resScaleUrl, width, height, postfix, true);
				res.setResScaleUrl(resScaleUrl);*/
                ImgUtil.compressPic(uploadPath + newName, uploadPath + scaleFileName, width, height, postfix, true);
                //数据库存储绝对路径
                res.setResScaleUrl(resScaleUrl);
            }
            fileMapper.insertSysResource(res);
            //插入完成后，将文件的相对路径改为绝对路径返回
			/*res.setResOriginalUrl(Statics.visitPath + resOriginalUrl);
			res.setResScaleUrl(Statics.visitPath + resScaleUrl);*/
//			res.setResScaleUrl(parentPath+ scaleFileName);
//			res.setResOriginalUrl(parentPath + newName);
            res.setResOriginalUrl(resOriginalUrl);
            res.setResScaleUrl(resScaleUrl);
            res.setResHostUrl(PathTool.getFullHostUrl(request,null));

        } catch (Exception e) {
            log.error("上传失败", e);
            res = new SysResource();
            res.setUploadStatus(false);
        }
        return res;
    }

    public SysResource executeUpload(HttpServletRequest request, Date date, String uploadPath, MultipartFile file, Integer imgWidth, Integer imgHeight) {
        SysResource res = new SysResource();
        if(file.isEmpty()){
            res.setUploadStatus(false);
            log.error("上传失败，因为文件是空的");
        }
        try {

            String originalName = file.getOriginalFilename();//文件原始名称
            String postfix = FileTool.getFileExt(originalName);//后缀名称
            String newName = PathTool.makeWebpicName(originalName,date);//文件新名称，随机数加时间防止重复
            String resOriginalUrl = PathTool.readAbsolutePath(request,newName);//原始文件相对路径
            String scaleFileName=PathTool.makeScaleFileName(newName,date);
            String resScaleUrl =PathTool.readScaleAbsolutePath(request,scaleFileName);//压缩文件相对路径
            FileUtil.writeFile(uploadPath , newName, file.getBytes());

            res.setUploadStatus(true);
            res.setCreateTime(new Date());
            res.setResName(originalName);
            res.setResOriginalUrl(resOriginalUrl);
            res.setResCutUrl("");
            res.setResScaleUrl("");
            res.setResSize(Integer.valueOf(String.valueOf(file.getSize())));
            res.setResStatus(0);
            res.setResType(postfix);
            String[] arr = IMG_POSTFIX.split(",");
            Boolean isImg = false;
            for (String str : arr) {
                if(str.equals(postfix.toUpperCase())){
                    isImg = true;
                    break;
                }
            }
            String parentPath= PathTool.readParentWebPath(request,newName);
            if(isImg){//对图片进行处理
                // ImgUtil.compressPic(uploadPath + resOriginalUrl, uploadPath + resScaleUrl, width, height, postfix, true);
                // res.setResScaleUrl(resScaleUrl);
                ImgUtil.compressPic(uploadPath + newName, uploadPath + scaleFileName, imgWidth, imgHeight, postfix, true);
                //数据库存储绝对路径
                res.setResScaleUrl(resScaleUrl);
            }
            res.setResScaleUrl(resScaleUrl);
            // res.setResScaleUrl(resScaleUrl);
            fileMapper.insertSysResource(res);

            res.setResOriginalUrl(resOriginalUrl);
            res.setResScaleUrl(resScaleUrl);
            res.setResHostUrl(PathTool.getFullHostUrl(request,null));

        }catch (Exception e) {
            log.error("上传失败", e);
            res = new SysResource();
            res.setUploadStatus(false);
        }

        return res;

    }
}
