package com.jusfoun.ydylsz.service;

import cn.hutool.core.util.URLUtil;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.Response;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import com.hikvision.artemis.sdk.util.HttpUtil;
import com.jusfoun.ydylsz.mapper.HlhtCapturePicMapper;
import com.jusfoun.ydylsz.pojo.HlhtCapturePicVo;
import com.jusfoun.ydylsz.pojo.OdsUpCnsptxxxjkFinalVo;
import com.jusfoun.ydylsz.secondaryMapper.OdsUpCnsptxxxjkFinalMapper;
import com.jusfoun.ydylsz.util.FileUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.UUIDUtils;
import lombok.extern.log4j.Log4j;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.*;
import java.net.URI;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * @author by PIG
 * 2022/9/23 15
 */
@Log4j
@Service("HlhtCapturePicService")
public class HlhtCapturePicService {

    @Autowired
    private HlhtCapturePicMapper capturePicMapper;

    @Autowired
    private OdsUpCnsptxxxjkFinalMapper odsUpCnsptxxxjkFinalMapper;

    @Value("${filesPath}")
    private String filesPath;

    static String HOST = "10.69.3.1:443";
    static String APPKEY = "24012924";
    static final String ARTEMIS_PATH = "/artemis";
    String appSecret = "uHzSYRUJpnCVCJSIEUWc";

    /*public List<HlhtCapturePicVo> listAllHw(Map<String, Object> param) {
        return capturePicMapper.listAllHw(param);
    }*/

    public void catchPic() {
        List<HlhtCapturePicVo> hlhtCapturePicVoList = capturePicMapper.listAllHw(null);

        int size = hlhtCapturePicVoList.size();
        log.info("监控点数量 = " + size);
        // artemis网关服务器ip端口
        ArtemisConfig.host = HOST;
        // 秘钥appKey
        ArtemisConfig.appKey = APPKEY;
        // 秘钥appSecret
        ArtemisConfig.appSecret = appSecret;

        final String online_URL = ARTEMIS_PATH + "/api/video/v1/manualCapture";
        HashMap<String, String> path = new HashMap<String, String>(2) {{
            put("https://", online_URL);
        }};
        String contentType = "application/json";
        hlhtCapturePicVoList.parallelStream().forEach(item -> {
            String cameraIndexCode = item.getJkdbm();
            JSONObject jsonBody = new JSONObject();
            jsonBody.put("cameraIndexCode", cameraIndexCode);
            String body = jsonBody.toJSONString();
            String resultData = ArtemisHttpUtil.doPostStringArtemis(path, body, null, null, contentType, null);
            if (null == resultData) {
                log.error("cameraIndexCode === " + cameraIndexCode + " timeout =========");
            } else {
                JSONObject resData = JSONObject.parseObject(resultData);
                String code = resData.getString("code");
                if ("0".equals(code)) {
                    String picUrl = resData.getJSONObject("data").getString("picUrl");
                    //item.setUrl_path(picUrl);
                    byte[] pic = getPicStream(picUrl);
                    if (Objects.isNull(pic)) {
                        log.error(cameraIndexCode + "无法获取图片");
                    } else {
                        item.setFid(UUID.randomUUID().toString().replace("-", ""));
                        item.setZpsj(LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
                        //item.setFile_str(FileUtil.toHexString(pic));
                        /*item.setCntxwjl(FileUtil.toHexString(pic));
                        item.setId(UUIDUtils.uuid());
                        item.setLoadDate(new Date());
                        item.setZhgxsj(item.getZpsj());
                        odsUpCnsptxxxjkFinalMapper.saveEntity(item);*/
                        if (pic.length > 0) {
                            String yearMonth = DateUtil.getNowDateFormat(DateUtil.YYYYMMDD);
                            String uploadDirStr = filesPath+File.separator+"cntp/"+yearMonth;
                            File uploadDir = new File(uploadDirStr);
                            if (!uploadDir.exists()) {
                                uploadDir.mkdirs();
                            }
                            InputStream in = new ByteArrayInputStream(pic);
                            String fileName = item.getHwdm()+"_"+LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMddHHmm"))+".jpg";
                            String filePath = uploadDirStr + File.separator + fileName;
                            File file = new File(filePath);
                            try {
                                FileOutputStream fos = new FileOutputStream(file);
                                byte[] b = new byte[1024];
                                int nRead = 0;
                                while ((nRead = in.read(b)) != -1) {
                                    fos.write(b, 0, nRead);
                                }
                                fos.flush();
                                fos.close();
                                in.close();
                            } catch (FileNotFoundException e) {
                                e.printStackTrace();
                            } catch (IOException e) {
                                e.printStackTrace();
                            }
                            item.setFileName(fileName);
                            item.setFileUrl("cntp/"+yearMonth + File.separator + fileName);
                        }
                        capturePicMapper.saveEntity(item);
                    }
                } else {
                    log.error("code = " + code + " \t " + resData.get("msg"));
                }
            }
        });
    }


    public byte[] getPicStream(String pic_url) {
        URI uri = URLUtil.toURI(pic_url);
        String host = uri.getScheme() + "://" + uri.getHost();
        String path = uri.getPath() + "?" + uri.getQuery();
        try {
            Response response = HttpUtil.httpImgGet(host, path, 50 * 1000, new HashMap<>(), null, null, APPKEY, "uHzSYRUJpnCVCJSIEUWc");
            HttpResponse httpResponse = response.getResponse();
            int statusCode = response.getStatusCode();
            if (200 == statusCode) {
                HttpEntity entity = httpResponse.getEntity();
                InputStream inputStream = entity.getContent();

                ByteArrayOutputStream output = new ByteArrayOutputStream();
                byte[] buffer = new byte[4096];
                int n = 0;
                while (-1 != (n = inputStream.read(buffer))) {
                    output.write(buffer, 0, n);
                }
                return output.toByteArray();
            } else {
                log.error("请求失败");
                return null;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    public PageInfo<HlhtCapturePicVo> getCnspt(Integer pageNo, Integer pageSize, HlhtCapturePicVo hlhtCapturePicVo) {
        PageHelper.startPage(pageNo, pageSize);
        if (null != hlhtCapturePicVo.getEndDate()) {
            hlhtCapturePicVo.setEndDate(hlhtCapturePicVo.getEndDate()+" 23:59:59");
        }
        if (null != hlhtCapturePicVo.getStartDate()) {
            hlhtCapturePicVo.setStartDate(hlhtCapturePicVo.getStartDate()+" 00:00:00");
        }
        List<HlhtCapturePicVo> list = capturePicMapper.getCnspt(hlhtCapturePicVo);
        return new PageInfo<HlhtCapturePicVo>(list);
    }
}
