package com.jusfoun.ydylsz.service;

import com.jusfoun.ydylsz.mapper.KcStatisticsMapper;
import com.jusfoun.ydylsz.pojo.*;
import com.jusfoun.ydylsz.utils.StringUtils;
import com.jusfoun.ydylsz.vo.KcStatisticsVO;
import com.jusfoun.ydylsz.vo.PzXzKcVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.*;
import java.util.function.BiConsumer;
import java.util.stream.Collectors;

@Service
public class KcStatisticsService {

    @Autowired
    private KcStatisticsMapper kcStatisticsMapper;

    public KcStatisticsVO selectKcStatisticsInfo() {
        return kcStatisticsMapper.selectKcStatisticsInfo();
    }

    public EchartsResp getPzBarChart(String xzqhdm, Integer type) {
        EchartsResp listData = new EchartsResp();
        LinkedHashSet<String> data = new LinkedHashSet<>();
        List<EchartsList3> series = new ArrayList<>();

        List<PzXzKcVO> kcList = kcStatisticsMapper.getPzXzKc(xzqhdm,type);
        for (PzXzKcVO vo: kcList) {
            List<BigDecimal> seriesDateValue = new ArrayList<>();
            EchartsList3 seriesData = new EchartsList3();
            data.add(vo.getPzlb());
            if (series.size()==0) {
                seriesData.setName(vo.getXzlb());
                seriesDateValue.add(vo.getSumLskc());
                seriesData.setData(seriesDateValue);
                series.add(seriesData);
            } else {
                boolean has = false;
                int hasIndex = 0;
                for (int i = 0; i < series.size(); i++) {
                    if (series.get(i).getName().equals(vo.getXzlb())) {
                        has = true;
                        hasIndex = i;
                        break;
                    }
                }
                if (has) {
                    series.get(hasIndex).getData().add(vo.getSumLskc());
                } else {
                    seriesData.setName(vo.getXzlb());
                    seriesDateValue.add(vo.getSumLskc());
                    seriesData.setData(seriesDateValue);
                    series.add(seriesData);
                }
            }
        }
        listData.setData(data);
        listData.setSeries(series);
        return listData;
    }

    public EchartsResp getScnfBarChart(PzXzKcVO kcvo) {
        EchartsResp listData = new EchartsResp();
        LinkedHashSet<String> data = new LinkedHashSet<>();
        List<EchartsList3> series = new ArrayList<>();
        List<EchartsList3> list = new ArrayList<>();
        BigDecimal zkc = new BigDecimal(0);

        List<PzXzKcVO> kcList = kcStatisticsMapper.getScnfBarChart(kcvo);
        LinkedHashSet<EchartsObj3> dataList = new LinkedHashSet<>();
        List<EchartsDouble> list2 = new ArrayList<>();
        Map<String, List<PzXzKcVO>> maps = kcList.stream().collect(Collectors.groupingBy(PzXzKcVO::getScnf));
        maps.forEach(new BiConsumer<String, List<PzXzKcVO>>(){
            @Override
            public void accept(String s, List<PzXzKcVO> pzXzKcVOS) {
                EchartsObj3 echartsObj3 = new EchartsObj3();
                List<EchartsDouble> list2 = new ArrayList<>();
                echartsObj3.setName(s);
                dataList.add(echartsObj3);

                pzXzKcVOS.forEach(pzvos->{
                    EchartsDouble echartsDouble = new EchartsDouble();
                    echartsDouble.setName(pzvos.getXzlb());
                    echartsDouble.setValue(pzvos.getSumLskc());
                    list2.add(echartsDouble);
                    echartsObj3.setList(list2);
                });

            }
        });

        for (PzXzKcVO vo: kcList) {
            List<BigDecimal> seriesDateValue = new ArrayList<>();
            EchartsList3 seriesData = new EchartsList3();

            EchartsList3 xzDate = new EchartsList3();
            data.add(vo.getScnf());
            if (series.size()==0) {
                seriesData.setName(vo.getXzlb());
                seriesDateValue.add(vo.getSumLskc());
                seriesData.setData(seriesDateValue);
                series.add(seriesData);
            } else {
                boolean has = false;
                int hasIndex = 0;
                for (int i = 0; i < series.size(); i++) {
                    if (!StringUtils.isEmpty(series.get(i).getName())
                            && series.get(i).getName().equals(vo.getXzlb())) {
                        has = true;
                        hasIndex = i;
                        break;
                    }
                }
                if (has) {
                    series.get(hasIndex).getData().add(vo.getSumLskc());
                } else {
                    seriesData.setName(vo.getXzlb());
                    seriesDateValue.add(vo.getSumLskc());
                    seriesData.setData(seriesDateValue);
                    series.add(seriesData);
                }
            }
            zkc = zkc.add(vo.getSumLskc());
        }
        listData.setData(data);
        listData.setSeries(series);
        listData.setDataList(dataList);
        listData.setZkc(zkc);
        return listData;
    }

    public EchartsResp getDjBarChart(PzXzKcVO kcvo) {
        EchartsResp listData = new EchartsResp();
        LinkedHashSet<String> data = new LinkedHashSet<>();
        List<EchartsList3> series = new ArrayList<>();
        List<EchartsList3> list = new ArrayList<>();
        BigDecimal zkc = new BigDecimal(0);

        List<PzXzKcVO> kcList = kcStatisticsMapper.getDjKc(kcvo);
        LinkedHashSet<EchartsObj3> dataList = new LinkedHashSet<>();
        List<EchartsDouble> list2 = new ArrayList<>();
        Map<String, List<PzXzKcVO>> maps = kcList.stream().collect(Collectors.groupingBy(PzXzKcVO::getXzlb));
        maps.forEach(new BiConsumer<String, List<PzXzKcVO>>(){
            @Override
            public void accept(String s, List<PzXzKcVO> pzXzKcVOS) {
                EchartsObj3 echartsObj3 = new EchartsObj3();
                List<EchartsDouble> list2 = new ArrayList<>();
                echartsObj3.setName(s);
                dataList.add(echartsObj3);

                pzXzKcVOS.forEach(pzvos->{
                    EchartsDouble echartsDouble = new EchartsDouble();
                    echartsDouble.setName(pzvos.getLsdjmc());
                    echartsDouble.setValue(pzvos.getSumLskc());
                    list2.add(echartsDouble);
                    echartsObj3.setList(list2);
                });

            }
        });

        for (PzXzKcVO vo: kcList) {
            List<BigDecimal> seriesDateValue = new ArrayList<>();
            EchartsList3 seriesData = new EchartsList3();

            EchartsList3 xzDate = new EchartsList3();
            data.add(vo.getXzlb());
            if (series.size()==0) {
                seriesData.setName(vo.getLsdjmc());
                seriesDateValue.add(vo.getSumLskc());
                seriesData.setData(seriesDateValue);
                series.add(seriesData);
            } else {
                boolean has = false;
                int hasIndex = 0;
                for (int i = 0; i < series.size(); i++) {
                    if (!StringUtils.isEmpty(series.get(i).getName())
                            && series.get(i).getName().equals(vo.getLsdjmc())) {
                        has = true;
                        hasIndex = i;
                        break;
                    }
                }
                if (has) {
                    series.get(hasIndex).getData().add(vo.getSumLskc());
                } else {
                    seriesData.setName(vo.getLsdjmc());
                    seriesDateValue.add(vo.getSumLskc());
                    seriesData.setData(seriesDateValue);
                    series.add(seriesData);
                }
            }
            zkc = zkc.add(vo.getSumLskc());
        }
        listData.setData(data);
        listData.setSeries(series);
        listData.setDataList(dataList);
        listData.setZkc(zkc);
        return listData;
    }

    public List<Map<String,Object>> selectAllData() {
        List<Map<String,Object>> list = new ArrayList<>();
        list = kcStatisticsMapper.selectAllData();
        return list;
    }

    public Map<String,List<Map<String,Object>>> selectXzPzByKdmc(String kdmc) {
        Map<String,List<Map<String,Object>>> res = new HashMap<>();
        List<List<Map<String,Object>>> list = new ArrayList<>();
        List<Map<String,Object>> xzList  = kcStatisticsMapper.selectXzCount(kdmc);
        List<Map<String,Object>> pzList  = kcStatisticsMapper.selectPzCount(kdmc);
        res.put("data1",xzList);
        res.put("data2",pzList);
        return res;
    }
}
