package com.jusfoun.ydylsz.webSocket;

import com.jusfoun.ydylsz.service.*;
import com.jusfoun.ydylsz.service.zjbg.ZjbgService;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

/**
 * 
 * @Description：检查计划定时任务
 * @author：王帅
 * @date: 2020年1月10日 下午2:51:50
 */
@ConditionalOnProperty(prefix = "scheduling", name = "enabled", havingValue = "true")
@Component
@Log4j
public class TaskSchedule {
	
	@Autowired
	private LsKcxxService lsKcxxService;
	
	@Autowired
	private LsrkService lsrkService;
	
	@Autowired
	private LsckService lsckService;
	
	@Autowired
	private LsrkjyService lsrkjyService;
	
	@Autowired
	private LsckjyService lsckjyService;

	@Autowired
	private ZjbgService zjbgService;

	/**
	 * 
	 * @Description: 修改计划状态->所有子任务完成后修改计划为已完成(每五分钟执行一次)
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	//@Scheduled(cron = "0 */10 * * * ?")
	//@Scheduled(cron = "0 41 17 ? * *")
	@Scheduled(cron="0 0 0,12 * * ?")
	public void updateData() {
		//更新库存
		try {
			lsKcxxService.update();
			log.info("库存信息同步结束");
		} catch (Exception e) {
			e.printStackTrace();
			log.info("库存信息同步失败 {}" +e.getMessage());
		}
		//更新入库
		try {
			lsrkService.update();
			log.info("入库信息同步结束");
		} catch (Exception e) {
			log.info("入库信息同步失败 {}" +e.getMessage());
		}
//		//更新出库
		try {
			lsckService.update();
			log.info("出库信息同步结束");
		} catch (Exception e) {
			log.info("出库信息同步失败 {}" +e.getMessage());
		}
		//更新入库检验
		try {
			lsrkjyService.update();
			log.info("入库检验信息同步结束");
		} catch (Exception e) {
			log.info("入库检验信息同步失败 {}" +e.getMessage());
		}
//		//更新出库质检
		try {
			lsckjyService.update();
			log.info("出库检验信息同步结束");
		} catch (Exception e) {
			log.info("出库检验信息同步失败 {}" +e.getMessage());
		}

		//更新质检报告
		try {
			zjbgService.synchronData();
			log.info("质检报告信息同步结束");
		} catch (Exception e) {
			log.info("质检报告信息同步失败 {}" +e.getMessage());
		}
	}

    /**
     * 删除废弃数据
     */
    public void deleteDiscard() {

    }
}
